@@ -29,6 +29,7 @@
 #include <json-glib/json-glib.h>
 #include <webkit/webkit.h>
 
+#include "goalogging.h"
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
 #include "goaoauth2provider.h"
@@ -151,6 +152,7 @@ get_identity_sync (GoaOAuth2Provider  *provider,
                    GCancellable       *cancellable,
                    GError            **error)
 {
+  GError *identity_error;
   RestProxy *proxy;
   RestProxyCall *call;
   JsonParser *parser;
@@ -160,6 +162,8 @@ get_identity_sync (GoaOAuth2Provider  *provider,
   gchar *presentation_identity;
 
   ret = NULL;
+
+  identity_error = NULL;
   proxy = NULL;
   call = NULL;
   parser = NULL;
@@ -190,9 +194,16 @@ get_identity_sync (GoaOAuth2Provider  *provider,
   if (!json_parser_load_from_data (parser,
                                    rest_proxy_call_get_payload (call),
                                    rest_proxy_call_get_payload_length (call),
-                                   error))
+                                   &identity_error))
     {
-      g_prefix_error (error, _("Error parsing response as JSON: "));
+      goa_warning ("json_parser_load_from_data() failed: %s (%s, %d)",
+                   identity_error->message,
+                   g_quark_to_string (identity_error->domain),
+                   identity_error->code);
+      g_set_error (error,
+                   GOA_ERROR,
+                   GOA_ERROR_FAILED,
+                   _("Could not parse response"));
       goto out;
     }
 
@@ -200,10 +211,11 @@ get_identity_sync (GoaOAuth2Provider  *provider,
   id = g_strdup (json_object_get_string_member (json_object, "id"));
   if (id == NULL)
     {
+      goa_warning ("Did not find id in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
-                   _("Didn't find id member in JSON data"));
+                   _("Could not parse response"));
       goto out;
     }
 
@@ -211,10 +223,11 @@ get_identity_sync (GoaOAuth2Provider  *provider,
   presentation_identity = g_strdup (json_object_get_string_member (json_object, "account"));
   if (presentation_identity == NULL)
     {
+      goa_warning ("Did not find emails.account in JSON data");
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
-                   _("Didn't find account email member in JSON data"));
+                   _("Could not parse response"));
       goto out;
     }
 
@@ -227,6 +240,7 @@ get_identity_sync (GoaOAuth2Provider  *provider,
     }
 
  out:
+  g_clear_error (&identity_error);
   g_free (id);
   g_free (presentation_identity);
   if (call != NULL)
